pub struct DefaultComposeFilter;Expand description
Default composition filter implementing standard label matching.
This filter matches arcs when arc1.olabel == arc2.ilabel, handling epsilon
transitions by allowing them to match any label. The composed arc takes
ilabel from arc1 and olabel from arc2.
Epsilon Handling
- Epsilon output from FST1 (
arc1.olabel == 0) matches any FST2 input - Epsilon input in FST2 (
arc2.ilabel == 0) matches any FST1 output - Both epsilon: composed arc is epsilon
Example
use arcweight::prelude::*;
let mut fst1 = VectorFst::<TropicalWeight>::new();
let s0 = fst1.add_state();
let s1 = fst1.add_state();
fst1.set_start(s0);
fst1.set_final(s1, TropicalWeight::one());
fst1.add_arc(s0, Arc::new(1, 2, TropicalWeight::new(0.5), s1));
let mut fst2 = VectorFst::<TropicalWeight>::new();
let t0 = fst2.add_state();
let t1 = fst2.add_state();
fst2.set_start(t0);
fst2.set_final(t1, TropicalWeight::one());
fst2.add_arc(t0, Arc::new(2, 3, TropicalWeight::new(0.3), t1));
// Compose using default filter
let result: VectorFst<TropicalWeight> = compose_default(&fst1, &fst2)?;Trait Implementations
Sourceimpl Clone for DefaultComposeFilter
impl Clone for DefaultComposeFilter
Sourcefn clone(&self) -> DefaultComposeFilter
fn clone(&self) -> DefaultComposeFilter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<W: Semiring> ComposeFilter<W> for DefaultComposeFilter
impl<W: Semiring> ComposeFilter<W> for DefaultComposeFilter
Sourcetype FilterState = ()
type FilterState = ()
Associated state type for tracking filter context across transitions. Read more
Sourcefn start() -> Self::FilterState
fn start() -> Self::FilterState
Returns the initial filter state for composition start.
Sourcefn filter_arc(
&self,
arc1: &Arc<W>,
arc2: &Arc<W>,
_fs: &Self::FilterState,
) -> Option<(Arc<W>, Self::FilterState)>
fn filter_arc( &self, arc1: &Arc<W>, arc2: &Arc<W>, _fs: &Self::FilterState, ) -> Option<(Arc<W>, Self::FilterState)>
Determines if two arcs can be composed and returns the resulting arc. Read more
impl Copy for DefaultComposeFilter
Sourceimpl Debug for DefaultComposeFilter
impl Debug for DefaultComposeFilter
Sourceimpl Default for DefaultComposeFilter
impl Default for DefaultComposeFilter
Sourcefn default() -> DefaultComposeFilter
fn default() -> DefaultComposeFilter
Returns the “default value” for a type. Read more